@@ -182,7 +182,8 @@ class AbstractEngine(ABC):
         raise NotImplementedError
 
     def __call__(self) -> Any:
-        self.apply()
+        if self.size != 0:
+            self.apply()
         self.set_success_ratio()
 
     def _operate(self, mini_batch):
@@ -418,12 +419,10 @@ class AbstractEngine(ABC):
         self._name = value
 
     def set_success_ratio(self) -> None:
-        try:
-            self._success_ratio = self._successful_documents / (
-                self.size * len(self.operators)
-            )
-        except ZeroDivisionError:
-            # if theres no documents just set success ratio at 1
+        if self.size:
+            denominator = self.size * len(self.operators)
+            self._success_ratio = self._successful_documents / denominator
+        else:
             self._success_ratio = 1
         logger.debug(format_logging_info({"success_ratio": self._success_ratio}))
 
